<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Ver letra das faixas</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Suplemento Lyrics</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="49"/>
        <source>About Lyrics Plugin</source>
        <translation>Sobre o suplemento Lyrics</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Suplemento Qmmp Lyrics</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Este suplemento obtém as letras através do sítio web LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation>Baseado em script Ultimate Lyrics de Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Suplemento Lyrics</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation>Serviço:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation>Faixa:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation>Ano:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Not found</source>
        <translation>Não encontrado</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="136"/>
        <source>Error: %1 - %2</source>
        <translation>Erro: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="149"/>
        <source>Receiving</source>
        <translation>Receção</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="204"/>
        <source>cache</source>
        <translation>cache</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation>Serviços disponíveis:</translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="119"/>
        <source>%1 (line: %2)</source>
        <translation>%1 (linha: %2)</translation>
    </message>
</context>
</TS>
